<?php
// $Id: flexifilter.conditions.inc,v 1.1 2008/01/08 03:06:35 cwgordon7 Exp $

/**
 * Implementation of hook_flexifilter_conditions()
 */
function flexifilter_flexifilter_conditions() {
  $conditions = array();
  $conditions['flexifilter_group_or'] = array(
    'label' => t('OR Group'),
    'description' => t('True if any of the contained conditions are true'),
    'contains_conditions' => TRUE,
    'callback' => 'flexifilter_condition_group_or',
    'group' => t('Logic'),
  );
  $conditions['flexifilter_group_and'] = array(
    'label' => t('AND Group'),
    'description' => t('True if all of the contained conditions are true'),
    'contains_conditions' => TRUE,
    'callback' => 'flexifilter_condition_group_and',
    'group' => t('Logic'),
  );
  $conditions['flexifilter_group_not'] = array(
    'label' => t('NOT Group'),
    'description' => t('True if any of the contained conditions are false'),
    'contains_conditions' => TRUE,
    'callback' => 'flexifilter_condition_group_not',
    'group' => t('Logic'),
  );
  $conditions['flexifilter_true'] = array(
    'label' => t('Always true'),
    'callback' => 'flexifilter_condition_constant',
    'callback_arguments' => array(TRUE),
    'group' => t('Logic'),
  );
  $conditions['flexifilter_false'] = array(
    'label' => t('Always false'),
    'callback' => 'flexifilter_condition_constant',
    'callback_arguments' => array(FALSE),
    'group' => t('Logic'),
  );
  $conditions['flexifilter_text_search'] = array(
    'label' => t('Text contains phrase'),
    'description' => t('True if the text contains the specified phrase. Can optionally use regular expressions.'),
    'callback' => 'flexifilter_condition_text_search',
    'group' => t('Text'),
  );
  $conditions['flexifilter_step_prepare'] = array(
    'label' => t('Is preparation step'),
    'description' => t('True only during the preparation step of filtering.'),
    'callback' => 'flexifilter_condition_step',
    'callback_arguments' => array('prepare'),
    'group' => t('Filtering Steps'),
    'is_advanced' => TRUE,
  );
  $conditions['flexifilter_step_process'] = array(
    'label' => t('Is processing step'),
    'description' => t('True only during the processing step of filtering.'),
    'callback' => 'flexifilter_condition_step',
    'callback_arguments' => array('process'),
    'group' => t('Filtering Steps'),
    'is_advanced' => TRUE,
  );
  return $conditions;
}

function flexifilter_condition_text_search($op, $settings, $text) {
  switch ($op) {
    case 'settings':
      $form = array();
      $form['find'] = array(
        '#type' => 'textfield',
        '#title' => t('Text to find'),
        '#default_value' => isset($settings['find']) ? $settings['find'] : '',
        '#required' => TRUE,
      );
      $form['is_regex'] = array(
        '#type' => 'checkbox',
        '#title' => t('Use regular expressions'),
        '#description' => t('If ticked, then the above text to find is interpreted as a regular expression.'),
        '#default_value' => isset($settings['is_regex']) ? $settings['is_regex'] : 0,
      );
      return $form;

    case 'prepare':
    case 'process':
      if (isset($settings['is_regex']) && $settings['is_regex'] == 1) {
        return preg_match('~'. str_replace('~', '\~', $settings['find']) .'~', $text) == 1;
      }
      else {
        return strpos($text, $settings['find']) !== FALSE;
      }
  }
}

function flexifilter_condition_group_and($op, $settings, $text) {
  switch ($op) {
    case 'settings':
      $form = array();
      return $form;

    case 'prepare':
    case 'process':
      foreach ($settings['conditions'] as $condition) {
        if (flexifilter_invoke_condition($condition, $op, $text) == FALSE) {
          return FALSE;
        }
      }
      return TRUE;
  }
}

function flexifilter_condition_group_or($op, $settings, $text) {
  switch ($op) {
    case 'settings':
      $form = array();
      return $form;

    case 'prepare':
    case 'process':
      foreach ($settings['conditions'] as $condition) {
        if (flexifilter_invoke_condition($condition, $op, $text) == TRUE) {
          return TRUE;
        }
      }
      return FALSE;
  }
}

function flexifilter_condition_group_not($op, $settings, $text) {
  switch ($op) {
    case 'settings':
      $form = array();
      return $form;

    case 'prepare':
    case 'process':
      foreach ($settings['conditions'] as $condition) {
        if (flexifilter_invoke_condition($condition, $op, $text) == FALSE) {
          return TRUE;
        }
      }
      return FALSE;
  }
}

function flexifilter_condition_constant($constant, $op, $settings, $text) {
  switch ($op) {
    case 'settings':
      return array();

    case 'prepare':
    case 'process':
      return $constant;
  }
}

function flexifilter_condition_step($step, $op, $settings, $text) {
  switch ($op) {
    case 'settings':
      return array();

    case 'prepare':
    case 'process':
      return $step == $op;
  }
}